/*
By: Frank Kroondijk, 2006
More info:
http://www.overnight.nl
http://dotnetpret.blogspot.com
mail: fh_kroondijk@yaho%nospam%o.com
when used, leave this comment in place
*/
using System;
using System.Collections.Generic;
using System.Text;
using ZedGraph;
using System.Drawing;

namespace OvernightPowerAddIns.Classes.Chart
{
    public class SingleYBarChart
    {

        /*
        pointlist
         Title
         * color
         * symboltype
         
        
         */

        public SingleYBarChart(ref ZedGraph.ZedGraphControl GraphControl, string Title, string LabelX, string LabelY,  List<Line> Lines)
        {
            // Get a reference to the GraphPane instance in the ZedGraphControl
            GraphPane myPane = GraphControl.GraphPane;

            // Set the titles and axis labels
            myPane.Title.Text = Title;
            myPane.XAxis.Title.Text = LabelX;
            myPane.YAxis.Title.Text = LabelY;
            //myPane.Y2Axis.Title.Text = "Parameter B";

            // Make up some data points based on the Sine function
            PointPairList list;
            LineItem myCurve;

            foreach(Line myLine in Lines)
            {
                list = new PointPairList();

                foreach (Point myPoint in myLine.Points)
                {
                    list.Add(myPoint.X, myPoint.Y);
                }
                myCurve = myPane.AddCurve(myLine.Title, list, myLine.Color, myLine.SymbolType);                
                myCurve.Symbol.Fill = new Fill(myLine.SymbolColor);
            }

            // Show the x axis grid
            myPane.XAxis.MajorGrid.IsVisible = true;
            // Make the Y axis scale red
            myPane.YAxis.Scale.FontSpec.FontColor = Color.Red;
            myPane.YAxis.Title.FontSpec.FontColor = Color.Red;
            // turn off the opposite tics so the Y tics don't show up on the Y2 axis
            myPane.YAxis.MajorTic.IsOpposite = false;
            myPane.YAxis.MinorTic.IsOpposite = false;
            // Don't display the Y zero line
            myPane.YAxis.MajorGrid.IsZeroLine = false;
            // Align the Y axis labels so they are flush to the axis
            myPane.YAxis.Scale.Align = AlignP.Inside;
            // Manually set the axis range
            myPane.YAxis.Scale.Min = 0;
            //myPane.YAxis.Scale.Max = 5000;
            myPane.Y2Axis.Scale.FormatAuto = true;

            // Fill the axis background with a gradient
            myPane.Chart.Fill = new Fill(Color.White, Color.LightGray, 45.0f);

            // Add a text box with instructions
            TextObj text = new TextObj("Zoom: left mouse & drag\nPan: middle mouse & drag\nContext Menu: right mouse",
                0.05f, 0.95f, CoordType.ChartFraction, AlignH.Left, AlignV.Bottom);
            text.FontSpec.StringAlignment = StringAlignment.Near;
            myPane.GraphObjList.Add(text);

            // Enable scrollbars if needed
            GraphControl.IsShowHScrollBar = true;
            GraphControl.IsShowVScrollBar = true;
            GraphControl.IsAutoScrollRange = true;
            GraphControl.IsScrollY2 = true;

            // OPTIONAL: Show tooltips when the mouse hovers over a point
            GraphControl.IsShowPointValues = true;
            GraphControl.PointValueEvent += new ZedGraphControl.PointValueHandler(MyPointValueHandler);

            // OPTIONAL: Add a custom context menu item
            //zg1.ContextMenuBuilder += new ZedGraphControl.ContextMenuBuilderEventHandler(MyContextMenuBuilder );

            // OPTIONAL: Handle the Zoom Event
            //zg1.ZoomEvent += new ZedGraphControl.ZoomEventHandler( MyZoomEvent );

            // Size the control to fit the window
            //SetSize();

            // Tell ZedGraph to calculate the axis ranges
            // Note that you MUST call this after enabling IsAutoScrollRange, since AxisChange() sets
            // up the proper scrolling parameters
            GraphControl.AxisChange();
            // Make sure the Graph gets redrawn
            GraphControl.Invalidate();
        }
        /// <summary>
        /// Display customized tooltips when the mouse hovers over a point
        /// </summary>
        private string MyPointValueHandler(ZedGraphControl control, GraphPane pane,
                        CurveItem curve, int iPt)
        {
            // Get the PointPair that is under the mouse
            PointPair pt = curve[iPt];

            return curve.Label.Text + " is " + pt.Y.ToString("f2") + " units at " + pt.X.ToString("f1") + " days";
        }
    }
}
